@@ -40,7 +40,8 @@ from spyder.utils import icon_manager as ima
 from spyder.utils import misc, programs, vcs
 from spyder.utils.misc import getcwd_or_home
 from spyder.utils.qthelpers import (add_actions, create_action,
-                                    create_plugin_layout, file_uri)
+                                    create_plugin_layout, file_uri,
+                                    MENU_SEPARATOR, QInputDialogMultiline)
 
 try:
     from nbconvert import PythonExporter as nbexporter
@@ -159,6 +160,7 @@ class DirView(QTreeView):
         # Options
         self.name_filters = ['*.py']
         self.show_all = None
+        self.show_hidden = None
         self.single_click_to_open = False
         self.file_associations = {}
         self._last_column = 0
@@ -184,10 +186,7 @@ class DirView(QTreeView):
     #---- Model
     def setup_fs_model(self):
         """Setup filesystem model"""
-        filters = (QDir.AllDirs | QDir.Files | QDir.Drives
-                   | QDir.NoDotAndDotDot | QDir.Hidden)
         self.fsmodel = QFileSystemModel(self)
-        self.fsmodel.setFilter(filters)
         self.fsmodel.setNameFilterDisables(False)
 
     def install_model(self):
@@ -268,11 +267,21 @@ class DirView(QTreeView):
 
     def set_show_all(self, state):
         """Toggle 'show all files' state"""
+        self.filters_action.setDisabled(state)
         if state:
             self.fsmodel.setNameFilters([])
         else:
             self.fsmodel.setNameFilters(self.name_filters)
 
+    def set_show_hidden(self, state):
+        """Toggle 'show hidden files' state"""
+        filters = (QDir.AllDirs | QDir.Files | QDir.Drives |
+                   QDir.NoDotAndDotDot)
+        if state:
+            filters = (QDir.AllDirs | QDir.Files | QDir.Drives |
+                       QDir.NoDotAndDotDot | QDir.Hidden)
+        self.fsmodel.setFilter(filters)
+
     def get_filename(self, index):
         """Return filename associated with *index*"""
         if index:
@@ -303,12 +312,14 @@ class DirView(QTreeView):
 
     #---- Tree view widget
     def setup(self, name_filters=['*.py', '*.pyw'], show_all=False,
-              single_click_to_open=False, file_associations={}):
+              show_hidden=False, single_click_to_open=False,
+              file_associations={}):
         """Setup tree widget"""
         self.setup_view()
 
         self.set_name_filters(name_filters)
         self.show_all = show_all
+        self.show_hidden = show_hidden
         self.single_click_to_open = single_click_to_open
         self.set_file_associations(file_associations)
 
@@ -323,31 +334,42 @@ class DirView(QTreeView):
 
     #---- Context menu
     def setup_common_actions(self):
-        """Setup context menu common actions"""
+        """Set-up context menu common actions."""
+        # Show all files
+        self.all_action = create_action(
+            self,
+            _("Show all files"),
+            toggled=self.toggle_all)
+        # Show hidden files
+        self.hidden_action = create_action(
+            self,
+            _("Show hidden files"),
+            toggled=self.toggle_hidden,
+        )
         # Filters
         self.filters_action = create_action(
-            self, _("Edit filename filters..."), None, ima.icon('filter'),
+            self, _("Show files with these extensions..."), None,
+            ima.icon('filter'),
             triggered=self.edit_filter,
         )
-        # Show all files
-        self.all_action = create_action(self, _("Show all files"),
-                                        toggled=self.toggle_all)
-
-        # Show all files
+        # Single click
         self.single_click_to_open_action = create_action(
             self,
             _("Single click to open"),
             toggled=self.set_single_click_to_open,
         )
-        actions = [self.filters_action, self.all_action,
-                   self.single_click_to_open_action]
+
+        actions = [self.all_action, self.hidden_action, self.filters_action,
+                   MENU_SEPARATOR, self.single_click_to_open_action]
         self.update_common_actions()
         return actions
 
     def update_common_actions(self):
         """Update the status of widget actions based on stored state."""
         self.set_show_all(self.show_all)
+        self.set_show_hidden(self.show_hidden)
         self.all_action.setChecked(self.show_all)
+        self.hidden_action.setChecked(self.show_hidden)
         self.single_click_to_open_action.setChecked(self.single_click_to_open)
 
     def get_common_file_associations(self, fnames):
@@ -382,12 +404,15 @@ class DirView(QTreeView):
 
     @Slot()
     def edit_filter(self):
-        """Edit name filters"""
-        filters, valid = QInputDialog.getText(self, _('Edit filename filters'),
-                                              _('Name filters:'),
-                                              QLineEdit.Normal,
-                                              ", ".join(self.name_filters))
-        if valid:
+        """Edit name filters."""
+        dialog = QInputDialogMultiline(
+            self, _('Edit filename filters'),
+            _('Name filters:'),
+            ", ".join(self.name_filters))
+        dialog.resize(500, 300)
+        result = dialog.exec_()
+        if result:
+            filters = dialog.text_edit.toPlainText()
             filters = [f.strip() for f in to_text_string(filters).split(',')]
             self.parent_widget.sig_option_changed.emit('name_filters', filters)
             self.set_name_filters(filters)
@@ -399,23 +424,46 @@ class DirView(QTreeView):
         self.show_all = checked
         self.set_show_all(checked)
 
+    @Slot(bool)
+    def toggle_hidden(self, checked):
+        """Toggle hidden files."""
+        self.parent_widget.sig_option_changed.emit('show_hidden', checked)
+        self.show_hidden = checked
+        self.set_show_hidden(checked)
+
     def create_file_new_actions(self, fnames):
         """Return actions for submenu 'New...'"""
-        root_path = self.fsmodel.rootPath()
+        if not fnames:
+            root_path = self.fsmodel.rootPath()
+        else:
+            # Verify if the user is trying to add something new inside a folder
+            # so it can be added in that folder and not in the rootpath
+            # See spyder-ide/spyder#13444
+            level_list = []
+            current_index = self.currentIndex()
+            if current_index.isValid():
+                level_list.append(current_index.data())
+
+            while current_index.isValid():
+                current_index = current_index.parent()
+                if current_index.data() is not None:
+                    level_list.insert(0, current_index.data())
+
+            root_path = osp.join(*level_list)
+
         new_file_act = create_action(self, _("File..."),
-                                     icon=ima.icon('filenew'),
+                                     icon=ima.icon('TextFileIcon'),
                                      triggered=lambda:
                                      self.new_file(root_path))
-        new_module_act = create_action(self, _("Module..."),
-                                       icon=ima.icon('spyder'),
+        new_module_act = create_action(self, _("Python script..."),
+                                       icon=ima.icon('python'),
                                        triggered=lambda:
                                        self.new_module(root_path))
         new_folder_act = create_action(self, _("Folder..."),
-                                       icon=ima.icon('folder_new'),
+                                       icon=ima.icon('DirOpenIcon'),
                                        triggered=lambda:
                                        self.new_folder(root_path))
-        new_package_act = create_action(self, _("Package..."),
-                                        icon=ima.icon('package_new'),
+        new_package_act = create_action(self, _("Python Package..."),
                                         triggered=lambda:
                                         self.new_package(root_path))
         return [new_file_act, new_folder_act, None,
@@ -1630,7 +1678,7 @@ class ExplorerWidget(QWidget):
     open_dir = Signal(str)
 
     def __init__(self, parent=None, name_filters=['*.py', '*.pyw'],
-                 show_all=False, show_cd_only=None, show_icontext=True,
+                 show_all=False, show_hidden=False, show_cd_only=None,
                  single_click_to_open=False, file_associations={},
                  options_button=None, visible_columns=[0, 3]):
         QWidget.__init__(self, parent)
@@ -1645,22 +1693,24 @@ class ExplorerWidget(QWidget):
                                self.button_menu]
 
         # Actions
-        icontext_action = create_action(self, _("Show icons and text"),
-                                        toggled=self.toggle_icontext)
-        previous_action = create_action(self, text=_("Previous"),
-                            icon=ima.icon('ArrowBack'),
-                            triggered=self.treewidget.go_to_previous_directory)
-        next_action = create_action(self, text=_("Next"),
-                            icon=ima.icon('ArrowForward'),
-                            triggered=self.treewidget.go_to_next_directory)
-        parent_action = create_action(self, text=_("Parent"),
-                            icon=ima.icon('ArrowUp'),
-                            triggered=self.treewidget.go_to_parent_directory)
+        previous_action = create_action(
+            self, text=_("Previous"),
+            icon=ima.icon('ArrowBack'),
+            triggered=self.treewidget.go_to_previous_directory)
+        next_action = create_action(
+            self, text=_("Next"),
+            icon=ima.icon('ArrowForward'),
+            triggered=self.treewidget.go_to_next_directory)
+        parent_action = create_action(
+            self, text=_("Parent"),
+            icon=ima.icon('ArrowUp'),
+            triggered=self.treewidget.go_to_parent_directory)
 
         # Setup widgets
         self.treewidget.setup(
             name_filters=name_filters,
             show_all=show_all,
+            show_hidden=show_hidden,
             single_click_to_open=single_click_to_open,
             file_associations=file_associations,
         )
@@ -1688,8 +1738,9 @@ class ExplorerWidget(QWidget):
             self.display_column_actions.append(action)
 
         self.treewidget.chdir(getcwd_or_home())
-        self.treewidget.common_actions += [None, icontext_action, None]
-        self.treewidget.common_actions += self.display_column_actions
+        self.treewidget.common_actions = (
+            self.treewidget.common_actions[:-1] + self.display_column_actions
+            + [MENU_SEPARATOR] + self.treewidget.common_actions[-1:])
 
         button_previous.setDefaultAction(previous_action)
         previous_action.setEnabled(False)
@@ -1699,9 +1750,6 @@ class ExplorerWidget(QWidget):
 
         button_parent.setDefaultAction(parent_action)
 
-        self.toggle_icontext(show_icontext)
-        icontext_action.setChecked(show_icontext)
-
         for widget in self.action_widgets:
             widget.setAutoRaise(True)
             widget.setIconSize(QSize(16, 16))
@@ -1733,17 +1781,6 @@ class ExplorerWidget(QWidget):
                 action.setChecked(not is_hidden)
                 action.blockSignals(False)
 
-    @Slot(bool)
-    def toggle_icontext(self, state):
-        """Toggle icon text"""
-        self.sig_option_changed.emit('show_icontext', state)
-        for widget in self.action_widgets:
-            if widget is not self.button_menu:
-                if state:
-                    widget.setToolButtonStyle(Qt.ToolButtonTextBesideIcon)
-                else:
-                    widget.setToolButtonStyle(Qt.ToolButtonIconOnly)
-
 
 #==============================================================================
 # Tests
